@@ -1,3 +1,4 @@
+import traceback
 from functools import wraps
 from types import MethodType
 
@@ -10,9 +11,6 @@ from django_perf_rec.sql import sql_fingerprint
 
 
 class DBOp(Operation):
-    def __repr__(self):
-        return "DBOp({!r}, {!r})".format(repr(self.alias), repr(self.query))
-
     @property
     def name(self):
         name_parts = ["db"]
@@ -56,6 +54,7 @@ class DBRecorder:
                     DBOp(
                         alias=alias,
                         query=sql_fingerprint(sql, hide_columns=hide_columns),
+                        traceback=traceback.extract_stack(),
                     )
                 )
                 return sql
